package com.persagy.apm.energy.report.monthly.outline.service.builder.hotel.impl;

import com.persagy.apm.energy.report.monthly.detail.common.service.IReportDetailService;
import com.persagy.apm.energy.report.monthly.detail.hotel.area.model.dto.AddReportHotelAreaDetailDTO;
import com.persagy.apm.energy.report.monthly.detail.hotel.area.service.IReportHotelAreaDetailService;
import com.persagy.apm.energy.report.monthly.outline.model.ReportOutline;
import com.persagy.apm.energy.report.monthly.outline.service.builder.hotel.IHotelAreaReportBuilder;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.interceptor.TransactionAspectSupport;

import java.util.List;

/**
 * 酒店大区报告建造者
 *
 * @author lixing
 * @version V1.0 2021/5/12 2:53 下午
 **/
@Component
@Slf4j
public class HotelAreaReportBuilder implements IHotelAreaReportBuilder {
    @Autowired
    private IReportDetailService reportDetailService;
    @Autowired
    private IReportHotelAreaDetailService reportHotelAreaDetailService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean generateNewReportDetail(ReportOutline reportOutline) {
        try {
            AddReportHotelAreaDetailDTO addReportHotelAreaDetailDTO = new AddReportHotelAreaDetailDTO();
            // TODO: 2021/6/8
            String detailId = reportHotelAreaDetailService.createReportHotelAreaDetail(addReportHotelAreaDetailDTO);
            reportOutline.setDetailId(detailId);
            return true;
        } catch (Exception e) {
            log.error("生成报告失败", e);
            TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
            return false;
        }
    }

    /**
     * 获取段落包含的分组列表
     *
     * @param reportTypeId 报告类型id
     * @param paragraph 段落
     * @return 段落包含的分组列表
     * @author lixing
     * @version V1.0 2021/6/7 11:17 上午
     */
    private List<String> getGroupsByParagraph(String reportTypeId, String paragraph) {
        return reportDetailService.getGroupsByParagraph(reportTypeId, paragraph);
    }

    /**
     * 获取段落包含的功能点列表
     *
     * @param reportTypeId 报告类型id
     * @param paragraph 段落
     * @return 段落包含的功能点列表
     * @author lixing
     * @version V1.0 2021/6/7 11:17 上午
     */
    private List<String> getFunctionsByParagraph(String reportTypeId, String paragraph) {
        return reportDetailService.getFunctionsByParagraph(reportTypeId, paragraph);
    }
}
